@@ -19,65 +19,22 @@ static OLD_VERSION_MAX: Lazy<Version> = Lazy::new(|| Version::new(0, 4, 9));
 static OLD_VERSION_MIN: Lazy<Version> = Lazy::new(|| Version::new(0, 4, 0));
 
 static OLD_SOLC_RELEASES: Lazy<Releases> = Lazy::new(|| {
-    serde_json::from_str(
-        r#"{
-            "builds": [
-                {
-                    "version": "0.4.9",
-                    "sha256": "0x71da154585e0c9048445b39b3662b421d20814cc68482b6b072aae2e541a4c74"
-                },
-                {
-                    "version": "0.4.8",
-                    "sha256": "0xee76039f933938cb5c14bf3fc4754776aa3e5c4c88420413da4c0c13731b8ffe"
-                },
-                {
-                    "version": "0.4.7",
-                    "sha256": "0xe1affb6e13dee7b14039f8eb1a52343f5fdc56169023e0f7fc339dfc25ad2b3d"
-                },
-                {
-                    "version": "0.4.6",
-                    "sha256": "0x0525d7b95549db6c913edb3c1b0c26d2db81e64b03f8352261df1b2ad696a65e"
-                },
-                {
-                    "version": "0.4.5",
-                    "sha256": "0x6f46ab7747d7de1b75907e539e6e19be201680e64ce99b583c6356e4e7897406"
-                },
-                {
-                    "version": "0.4.4",
-                    "sha256": "0x25d148e9c1052631a930bfbe8e4e3d9dae8de7659f8d3ea659a3ef139cd5e2c9"
-                },
-                {
-                    "version": "0.4.3",
-                    "sha256": "0x1dc7ef0b4aab472299e77b39c7465cd5ed4609a759b52ce1a93f2d54395da73a"
-                },
-                {
-                    "version": "0.4.2",
-                    "sha256": "0x891d0b2d3a636ff40924802a6f5beb1ecbc42d5d0d0bfecbbb148b561c861fb9"
-                },
-                {
-                    "version": "0.4.1",
-                    "sha256": "0xa0c06d0c6a14c66ddeca1f065461fb0024de89421c1809a1b103b55c94e30860"
-                },
-                {
-                    "version": "0.4.0",
-                    "sha256": "0xe26d188284763684f3cf6d4900b72f7e45a050dd2b2707320273529d033cfd47"
-                }
-            ],
-            "releases": {
-                "0.4.9": "solc-v0.4.9",
-                "0.4.8": "solc-v0.4.8",
-                "0.4.7": "solc-v0.4.7",
-                "0.4.6":"solc-v0.4.6",
-                "0.4.5": "solc-v0.4.5",
-                "0.4.4":"solc-v0.4.4",
-                "0.4.3":"solc-v0.4.3",
-                "0.4.2":"solc-v0.4.2",
-                "0.4.1": "solc-v0.4.1",
-                "0.4.0": "solc-v0.4.0"
-            }
-        }"#,
+    serde_json::from_reader(
+        std::fs::File::open("./list/linux-arm64-old.json")
+            .expect("could not open list linux-arm64-old.json"),
     )
-    .expect("could not parse old solc list.json")
+    .expect("could not parse list linux-arm64-old.json")
+});
+
+static LINUX_AARCH64_URL_PREFIX: &str =
+    "https://github.com/nikitastupin/solc/raw/main/linux/aarch64";
+
+static LINUX_AARCH64_RELEASES: Lazy<Releases> = Lazy::new(|| {
+    serde_json::from_reader(
+        std::fs::File::open("./list/linux-aarch64.json")
+            .expect("could not open list linux-aarch64.json"),
+    )
+    .expect("could not parse list linux-aarch64.json")
 });
 
 /// Defines the struct that the JSON-formatted release list can be deserialized into.
@@ -158,6 +115,10 @@ where
 
 /// Fetch all releases available for the provided platform.
 pub async fn all_releases(platform: Platform) -> Result<Releases, SolcVmError> {
+    if platform == Platform::LinuxAarch64 {
+        return Ok(LINUX_AARCH64_RELEASES.clone());
+    }
+
     let releases = get(format!(
         "{}/{}/list.json",
         SOLC_RELEASES_URL,
@@ -193,6 +154,20 @@ pub fn artifact_url(
         ))?);
     }
 
+    if platform == Platform::LinuxAarch64 {
+        if LINUX_AARCH64_RELEASES.releases.contains_key(version) {
+            return Ok(Url::parse(&format!(
+                "{}/{}",
+                LINUX_AARCH64_URL_PREFIX, artifact
+            ))?);
+        } else {
+            return Err(SolcVmError::UnsupportedVersion(
+                version.to_string(),
+                platform.to_string(),
+            ));
+        }
+    }
+
     if platform == Platform::MacOsAmd64 && version.lt(&OLD_VERSION_MIN) {
         return Err(SolcVmError::UnsupportedVersion(
             version.to_string(),
@@ -218,6 +193,12 @@ mod tests {
         assert_eq!(OLD_SOLC_RELEASES.builds.len(), 10);
     }
 
+    #[test]
+    fn test_linux_aarch64() {
+        assert_eq!(LINUX_AARCH64_RELEASES.releases.len(), 43);
+        assert_eq!(LINUX_AARCH64_RELEASES.builds.len(), 43);
+    }
+
     #[tokio::test]
     async fn test_all_releases_macos() {
         assert!(all_releases(Platform::MacOsAmd64).await.is_ok());
